@@ -1,3 +1,4 @@
+import argparse
 import glob
 import hashlib
 import os.path
@@ -7,7 +8,7 @@ import semver
 import sentry_sdk
 
 from .client import login_to_server, upload, get_server_version, get_md5_from_file, check_token
-from .config import get_config_value, set_config_value
+from .config import get_config_value, set_config_value, get_optional_true_config_value
 from .constants import *
 from .exceptions import LoginException, UploadException
 from .helper import input_yn, print_error, print_warning
@@ -26,14 +27,25 @@ def main():
 
     try:
         server_url = get_config_value("shippy", "server")
-        token = get_config_value("shipper", "token")
+        token = get_config_value("shippy", "token")
 
         token = check_token_validity(server_url, token)
     except KeyError:
-        print("No configuration file found. You need to configure shippy before you can start using it.")
+        print("No configuration file found or configuration is invalid. You need to configure shippy before you can "
+              "start using it.")
         server_url = get_server_url()
         token = get_token(server_url)
 
+        # In case login function updated server URL, we need to fetch it again
+        server_url = get_config_value("shippy", "server")
+
+    # Check if we cannot prompt the user (default to auto-upload)
+    upload_without_prompt = get_optional_true_config_value("shippy", "UploadWithoutPrompt")
+
+    # Get commandline arguments
+    args = init_argparse()
+    upload_without_prompt = upload_without_prompt or args.yes
+
     check_server_compat(server_url)
 
     # Search current directory for files
@@ -47,7 +59,7 @@ def main():
         for build in builds:
             print("\t{}".format(build))
 
-        if len(builds) > 1:
+        if not upload_without_prompt and len(builds) > 1:
             print_warning("Warning: you seem to be uploading multiple builds. ", newline=False)
             if not input_yn("Are you sure you want to continue?", default=False):
                 return
@@ -58,14 +70,20 @@ def main():
                 print("Invalid build. Skipping...")
                 continue
 
-            if input_yn("Uploading build {}. Start?".format(build)):
+            if upload_without_prompt or input_yn("Uploading build {}. Start?".format(build)):
                 try:
                     upload(server_url=server_url,
                            build_file=build,
                            checksum_file="{}.md5".format(build),
                            token=token)
                 except UploadException as exception:
-                    print(exception)
+                    print_error(exception, newline=True, exit_after=False)
+
+
+def init_argparse():
+    parser = argparse.ArgumentParser(description="Client-side tool for interfacing with shipper")
+    parser.add_argument('-y', '--yes', action='store_true', help='Upload builds automatically without prompting')
+    return parser.parse_args()
 
 
 def check_server_compat(server_url):
@@ -183,7 +201,7 @@ def get_token(server_url):
 
             try:
                 token = login_to_server(username, password, server_url)
-                set_config_value("shipper", "token", token)
+                set_config_value("shippy", "token", token)
                 return token
             except LoginException as exception:
                 print_error("{} Please try again.".format(exception), newline=True, exit_after=False)
