@@ -3,9 +3,10 @@ from json import JSONDecodeError
 
 import requests
 
-from .exceptions import LoginException, UploadException
+from .config import get_config_value, set_config_value
 from .constants import UNHANDLED_EXCEPTION_MSG, FAILED_TO_RETRIEVE_SERVER_VERSION_ERROR_MSG, \
     CANNOT_CONTACT_SERVER_ERROR_MSG, FAILED_TO_LOG_IN_ERROR_MSG
+from .exceptions import LoginException, UploadException
 from .helper import ProgressBar, print_error
 
 
@@ -18,7 +19,7 @@ def handle_undefined_response(request):
 
 def get_server_version(server_url):
     """ Gets server version in semver format """
-    version_url = "{}/maintainers/api/system/".format(server_url)
+    version_url = "{}/api/v1/system/info/".format(server_url)
     try:
         r = requests.get(version_url)
         if r.status_code == 200:
@@ -32,21 +33,28 @@ def get_server_version(server_url):
 
 def login_to_server(username, password, server_url):
     """ Logs in to server and returns authorization token """
-    login_url = "{}/maintainers/api/login/".format(server_url)
+    login_url = "{}/api/v1/maintainers/login/".format(server_url)
     try:
         r = requests.post(login_url, data={'username': username, 'password': password})
 
         if r.status_code == 200:
             data = r.json()
             return data['token']
-        elif r.status_code == 400:
-            if r.json()['error'] == "blank_username_or_password":
-                raise LoginException("Username or password must not be blank.")
-        elif r.status_code == 404:
-            if r.json()['error'] == "invalid_credential":
-                raise LoginException("Invalid credentials!")
-        else:
-            handle_undefined_response(r)
+        elif r.status_code == 400 and r.json()['error'] == "blank_username_or_password":
+            raise LoginException("Username or password must not be blank.")
+        elif r.status_code == 404 and r.json()['error'] == "invalid_credential":
+            raise LoginException("Invalid credentials!")
+        # Really, really weird edge case where HTTP URLs would redirect and cause a GET request
+        elif r.status_code == 405 and r.json()['detail'] == 'Method "GET" not allowed.' and server_url[0:5] == "http:":
+            print("It seems like you entered a HTTP address when setting up shippy, but the server instance uses "
+                  "HTTPS. shippy automatically corrected your server URL in the configuration file.")
+            server_url = "https://{}".format(server_url[7:])
+            set_config_value("shippy", "server", server_url)
+            # Attempt logging in again
+            return login_to_server(username, password, server_url)
+
+        # Returned status code matches no scenario, abort
+        handle_undefined_response(r)
     except LoginException as e:
         raise e
     except requests.exceptions.RequestException:
@@ -54,18 +62,17 @@ def login_to_server(username, password, server_url):
 
 
 def check_token(server_url, token):
-    token_check_url = "{}/maintainers/api/token_check/".format(server_url)
+    token_check_url = "{}/api/v1/maintainers/token_check/".format(server_url)
     r = requests.get(token_check_url, headers={"Authorization": "Token {}".format(token)})
 
     if r.status_code == 200:
         print("Successfully validated token! Hello, {}.".format(r.json()['username']))
         return True
-    else:
-        return False
+    return False
 
 
 def upload(server_url, build_file, checksum_file, token):
-    device_upload_url = "{}/maintainers/api/chunked_upload/".format(server_url)
+    device_upload_url = "{}/api/v1/maintainers/chunked_upload/".format(server_url)
 
     chunk_size = 10000000  # 10 MB
     current_index = 0
@@ -84,8 +91,8 @@ def upload(server_url, build_file, checksum_file, token):
                 }, data={"filename": build_file}, files={'file': chunk_data})
 
                 if chunk_request.status_code == 200:
-                    device_upload_url = "{}/maintainers/api/chunked_upload/{}/".format(server_url,
-                                                                                       chunk_request.json()['id'])
+                    device_upload_url = "{}/api/v1/maintainers/chunked_upload/{}/".format(server_url,
+                                                                                          chunk_request.json()['id'])
                     current_index += len(chunk_data)
                     bar.show(current_index)
 
@@ -109,6 +116,9 @@ def upload(server_url, build_file, checksum_file, token):
                                          data={'md5': get_md5_from_file(checksum_file)})
 
         upload_exception_check(finalize_request, build_file)
+
+        # Check if build should be disabled immediately after run
+        check_build_disable(server_url, token, finalize_request.json()['build_id'])
     except UploadException as e:
         raise e
     except requests.exceptions.RequestException:
@@ -152,8 +162,27 @@ def upload_exception_check(request, build_file):
         if request.json()['error'] == "insufficient_permissions":
             raise UploadException("You are not allowed to upload for this device!")
     elif request.status_code == 404:
-        raise UploadException("Generic upload error. Make sure your device exists within shipper (contact an admin!)")
+        raise UploadException("Your device isn't registered on shipper. Please contact an admin to add your device.")
     elif int(request.status_code / 100) == 5:
-        raise UploadException("Something went wrong with the server. Please contact the admins.")
+        raise UploadException("An internal server error occurred. Please contact the admins.")
 
     handle_undefined_response(request)
+
+
+def check_build_disable(server_url, token, build_id):
+    try:
+        disable_build_on_upload = (get_config_value("shippy", "DisableBuildOnUpload") == "true")
+    except KeyError:
+        # Not defined
+        return
+
+    if disable_build_on_upload:
+        disable_build_url = "{}/api/v1/maintainers/build/enabled_status_modify/".format(server_url)
+        r = requests.get(disable_build_url, headers={"Authorization": "Token {}".format(token)},
+                         data={"build_id": build_id, "enable": False})
+
+        if r.status_code == 200:
+            print("Build has been automatically disabled, following configuration.")
+            print("If this is unexpected, please check your configuration.")
+        else:
+            print("There was a problem disabling the build.")
