@@ -18,7 +18,7 @@ class ProgressBar(Bar):
             self.etadelta = time.time()
             self.ittimes = \
                 self.ittimes[-ETA_SMA_WINDOW:] + \
-                    [-(self.start - time.time()) / (progress+1)]
+                [-(self.start - time.time()) / (progress + 1)]
             self.eta = \
                 sum(self.ittimes) / float(len(self.ittimes)) * \
                 (self.expected_size - progress)
@@ -56,5 +56,12 @@ def input_yn(question, default=True):
             print("Please respond with 'yes' or 'no' (or 'y' or 'n').")
 
 
-def print_error_tag():
-    puts(colored.red("ERROR: "), newline=False)
+def print_error(msg, newline, exit_after):
+    puts(colored.red("ERROR: {}".format(msg)), newline=newline)
+
+    if exit_after:
+        exit(1)
+
+
+def print_warning(msg, newline):
+    puts(colored.yellow("Warning: {}".format(msg)), newline=newline)
